window.Gleam.initSearch([{"doc":"simplifile","title":"simplifile","content":"# simplifile\n\n[![Package Version](https://img.shields.io/hexpm/v/simplifile)](https://hex.pm/packages/simplifile)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/simplifile/)\n\nSimplifile provides basic file operations (read, write, append, and delete) that work\nfor all targets (Erlang, Node, and Deno). It also provides functions for working with directories.\n\n## Example\n```gleam\nlet filepath = &quot;./test/hello.txt&quot;\nlet assert Ok(_) = &quot;Hello, World&quot; |&gt; write(to: filepath)\nlet assert Ok(_) = &quot;Goodbye, Mars&quot; |&gt; append(to: filepath)\nlet assert Ok(&quot;Hello, WorldGoodbye, Mars&quot;) = read(from: filepath)\nlet assert Ok(_) = delete(filepath)\nlet assert Error(_) = read(from: filepath)\n```\n\n## Quick start\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n\n## Installation\n\nIf available on Hex this package can be added to your Gleam project:\n\n```sh\ngleam add simplifile\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/simplifile&gt;.\n","url":"index.html"},{"doc":"simplifile","title":"FileError","content":"pub type FileError {\n  Eacces\n  Eagain\n  Ebadf\n  Ebadmsg\n  Ebusy\n  Edeadlk\n  Edeadlock\n  Edquot\n  Eexist\n  Efault\n  Efbig\n  Eftype\n  Eintr\n  Einval\n  Eio\n  Eisdir\n  Eloop\n  Emfile\n  Emlink\n  Emultihop\n  Enametoolong\n  Enfile\n  Enobufs\n  Enodev\n  Enolck\n  Enolink\n  Enoent\n  Enomem\n  Enospc\n  Enosr\n  Enostr\n  Enosys\n  Enotblk\n  Enotdir\n  Enotsup\n  Enxio\n  Eopnotsupp\n  Eoverflow\n  Eperm\n  Epipe\n  Erange\n  Erofs\n  Espipe\n  Esrch\n  Estale\n  Etxtbsy\n  Exdev\n  NotUtf8\n  Unknown\n}\n This type represents all of the reasons for why a file system operation could fail.\n\n Most of these reasons are POSIX errors, which come from the operating system\n and start with E. Others have been added to represent other issues that may\n arise specific to this library.\n\nEacces\n Permission denied.\n\nEagain\n Resource temporarily unavailable.\n\nEbadf\n Bad file number\n\nEbadmsg\n Bad message.\n\nEbusy\n File busy.\n\nEdeadlk\n Resource deadlock avoided.\n\nEdeadlock\n On most architectures, same as `Edeadlk`. On some architectures, it\n means &quot;File locking deadlock error.&quot;\n\nEdquot\n Disk quota exceeded.\n\nEexist\n File already exists.\n\nEfault\n Bad address in system call argument.\n\nEfbig\n File too large.\n\nEftype\n Inappropriate file type or format. Usually caused by trying to set the\n &quot;sticky bit&quot; on a regular file (not a directory).\n\nEintr\n Interrupted system call.\n\nEinval\n Invalid argument.\n\nEio\n I/O error.\n\nEisdir\n Illegal operation on a directory.\n\nEloop\n Too many levels of symbolic links.\n\nEmfile\n Too many open files.\n\nEmlink\n Too many links.\n\nEmultihop\n Multihop attempted.\n\nEnametoolong\n Filename too long\n\nEnfile\n File table overflow\n\nEnobufs\n No buffer space available.\n\nEnodev\n No such device.\n\nEnolck\n No locks available.\n\nEnolink\n Link has been severed.\n\nEnoent\n No such file or directory.\n\nEnomem\n Not enough memory.\n\nEnospc\n No space left on device.\n\nEnosr\n No STREAM resources.\n\nEnostr\n Not a STREAM.\n\nEnosys\n Function not implemented.\n\nEnotblk\n Block device required.\n\nEnotdir\n Not a directory.\n\nEnotsup\n Operation not supported.\n\nEnxio\n No such device or address.\n\nEopnotsupp\n Operation not supported on socket.\n\nEoverflow\n Value too large to be stored in data type.\n\nEperm\n Not owner.\n\nEpipe\n Broken pipe.\n\nErange\n Result too large.\n\nErofs\n Read-only file system.\n\nEspipe\n Invalid seek.\n\nEsrch\n No such process.\n\nEstale\n Stale remote file handle.\n\nEtxtbsy\n Text file busy.\n\nExdev\n Cross-domain link.\n\nNotUtf8\n File was requested to be read as UTF-8, but is not UTF-8 encoded.\n\nUnknown\n Any error not accounted for by this type\n\nSynonyms:\nsimplifile.FileError\nsimplifile FileError","url":"simplifile.html#FileError"},{"doc":"simplifile","title":"append","content":"pub fn append(contents: String, to filepath: String) -&gt; Result(\n  Nil,\n  FileError,\n)\n Append a string to the contents of a file at the given path\n ## Example\n \n let assert Ok(Nil) = append(&quot;more text&quot;, to: &quot;./needs_more_text.txt&quot;)\n \n\nSynonyms:\nsimplifile.append\nsimplifile append","url":"simplifile.html#append"},{"doc":"simplifile","title":"append_bits","content":"pub fn append_bits(bits: BitString, to filepath: String) -&gt; Result(\n  Nil,\n  FileError,\n)\n Append a bitstring to the contents of a file at the given path\n ## Example\n \n let assert Ok(Nil) = append_bits(&lt;&lt;&quot;more text&quot;:utf8&gt;&gt;, to: &quot;./needs_more_text.txt&quot;)\n \n\nSynonyms:\nsimplifile.append_bits\nsimplifile append_bits","url":"simplifile.html#append_bits"},{"doc":"simplifile","title":"delete","content":"pub fn delete(file_at filepath: String) -&gt; Result(Nil, FileError)\n Delete a file at a given filepath\n ## Example\n \n let assert Ok(Nil) = delete(file_at: &quot;./delete_me.txt&quot;)\n \n\nSynonyms:\nsimplifile.delete\nsimplifile delete","url":"simplifile.html#delete"},{"doc":"simplifile","title":"delete_directory","content":"pub fn delete_directory(filepath: String) -&gt; Result(\n  Nil,\n  FileError,\n)\n Delete a directory at the provided filepath\n\n ## Example\n \n delete_directory(&quot;./test&quot;)\n \nSynonyms:\nsimplifile.delete_directory\nsimplifile delete_directory","url":"simplifile.html#delete_directory"},{"doc":"simplifile","title":"is_directory","content":"pub fn is_directory(filepath: String) -&gt; Bool\n Checks if the provided filepath is a directory\n ## Example\n \n let assert True = is_directory(&quot;./test&quot;)\n \nSynonyms:\nsimplifile.is_directory\nsimplifile is_directory","url":"simplifile.html#is_directory"},{"doc":"simplifile","title":"list_contents","content":"pub fn list_contents(of directory: String) -&gt; Result(\n  List(String),\n  FileError,\n)\n Lists the contents of a directory.\n The list contains directory and file names, and is not recursive.\n \n ## Example\n \n let assert Ok(files_and_folders) = list_contents(of: &quot;./Folder1&quot;)\n \n \nSynonyms:\nsimplifile.list_contents\nsimplifile list_contents","url":"simplifile.html#list_contents"},{"doc":"simplifile","title":"make_directory","content":"pub fn make_directory(filepath: String) -&gt; Result(Nil, FileError)\n Make a directory at the provided filepath\n\n ## Example\n \n make_directory(&quot;./test&quot;)\n \nSynonyms:\nsimplifile.make_directory\nsimplifile make_directory","url":"simplifile.html#make_directory"},{"doc":"simplifile","title":"read","content":"pub fn read(from filepath: String) -&gt; Result(String, FileError)\n Read a files contents as a string\n ## Example\n \n let assert Ok(records) = read(from: &quot;./users.csv&quot;)\n \n\nSynonyms:\nsimplifile.read\nsimplifile read","url":"simplifile.html#read"},{"doc":"simplifile","title":"read_bits","content":"pub fn read_bits(from filepath: String) -&gt; Result(\n  BitString,\n  FileError,\n)\n Read a files contents as a bitstring\n ## Example\n \n let assert Ok(records) = read_bits(from: &quot;./users.csv&quot;)\n \n\nSynonyms:\nsimplifile.read_bits\nsimplifile read_bits","url":"simplifile.html#read_bits"},{"doc":"simplifile","title":"write","content":"pub fn write(contents: String, to filepath: String) -&gt; Result(\n  Nil,\n  FileError,\n)\n Write a string to a file at the given path\n ## Example\n \n let assert Ok(Nil) = write(&quot;Hello, World!&quot;, to: &quot;./hello_world.txt&quot;)\n \n\nSynonyms:\nsimplifile.write\nsimplifile write","url":"simplifile.html#write"},{"doc":"simplifile","title":"write_bits","content":"pub fn write_bits(bits: BitString, to filepath: String) -&gt; Result(\n  Nil,\n  FileError,\n)\n Write a bitstring to a file at the given path\n ## Example\n \n let assert Ok(Nil) = write_bits(&lt;&lt;&quot;Hello, World!&quot;:utf8&gt;&gt;, to: &quot;./hello_world.txt&quot;)\n \n\nSynonyms:\nsimplifile.write_bits\nsimplifile write_bits","url":"simplifile.html#write_bits"},{"doc":"simplifile","title":"simplifile","content":"","url":"simplifile.html"}]);